@@ -31,7 +31,7 @@
 
 const QChar recordSep(30);
 const QChar unitSep(31);
-const QChar messageEnd = 29;
+const QChar messageEnd(29);
 
 PythonSession::PythonSession(Cantor::Backend* backend) : Session(backend)
 {
@@ -51,7 +51,7 @@ PythonSession::~PythonSession()
 void PythonSession::login()
 {
     qDebug()<<"login";
-    emit loginStarted();
+    Q_EMIT loginStarted();
 
     if (m_process)
         m_process->deleteLater();
@@ -71,8 +71,8 @@ void PythonSession::login()
     if (!m_process->waitForStarted())
     {
         changeStatus(Session::Disable);
-        emit error(i18n("Failed to start Python, please check Python installation."));
-        emit loginDone();
+        Q_EMIT error(i18n("Failed to start Python, please check Python installation."));
+        Q_EMIT loginDone();
         delete m_process;
         m_process = nullptr;
         return;
@@ -122,7 +122,7 @@ void PythonSession::login()
     }
 
     changeStatus(Session::Done);
-    emit loginDone();
+    Q_EMIT loginDone();
 }
 
 void PythonSession::logout()
@@ -277,15 +277,15 @@ void PythonSession::reportServerProcessError(QProcess::ProcessError serverError)
     switch(serverError)
     {
         case QProcess::Crashed:
-            emit error(i18n("Cantor Python server stopped working."));
+            Q_EMIT error(i18n("Cantor Python server stopped working."));
             break;
 
         case QProcess::FailedToStart:
-            emit error(i18n("Failed to start Cantor python server."));
+            Q_EMIT error(i18n("Failed to start Cantor python server."));
             break;
 
         default:
-            emit error(i18n("Communication with Cantor python server failed for unknown reasons."));
+            Q_EMIT error(i18n("Communication with Cantor python server failed for unknown reasons."));
             break;
     }
     reportSessionCrash();
