@@ -109,7 +109,7 @@ void SageSession::login()
     qDebug()<<"login";
     if (m_process)
         return;
-    emit loginStarted();
+    Q_EMIT loginStarted();
 
     updateSageVersion();
 
@@ -123,8 +123,8 @@ void SageSession::login()
     if (!m_process->waitForStarted())
     {
         changeStatus(Session::Disable);
-        emit error(i18n("Failed to start Sage, please check Sage installation."));
-        emit loginDone();
+        Q_EMIT error(i18n("Failed to start Sage, please check Sage installation."));
+        Q_EMIT loginDone();
         delete m_process;
         m_process = nullptr;
         return;
@@ -192,7 +192,7 @@ void SageSession::login()
     }
 
     changeStatus(Session::Done);
-    emit loginDone();
+    Q_EMIT loginDone();
 }
 
 void SageSession::logout()
@@ -375,7 +375,7 @@ void SageSession::reportProcessError(QProcess::ProcessError e)
     if(e == QProcess::FailedToStart)
     {
         changeStatus(Cantor::Session::Done);
-        emit error(i18n("Failed to start Sage"));
+        Q_EMIT error(i18n("Failed to start Sage"));
     }
 }
 
