@@ -45,7 +45,7 @@ void ScilabSession::login()
     if (m_process)
         return;
 
-    emit loginStarted();
+    Q_EMIT loginStarted();
 
     QStringList args;
 
@@ -64,8 +64,8 @@ void ScilabSession::login()
     if (!m_process->waitForStarted())
     {
         changeStatus(Session::Disable);
-        emit error(i18n("Failed to start Scilab, please check Scilab installation."));
-        emit loginDone();
+        Q_EMIT error(i18n("Failed to start Scilab, please check Scilab installation."));
+        Q_EMIT loginDone();
         delete m_process;
         m_process = nullptr;
         return;
@@ -108,7 +108,7 @@ void ScilabSession::login()
 
     changeStatus(Cantor::Session::Done);
 
-    emit loginDone();
+    Q_EMIT loginDone();
 }
 
 void ScilabSession::logout()
@@ -154,7 +154,8 @@ void ScilabSession::interrupt()
             ; //TODO: interrupt the process on windows
 #endif
         }
-        foreach (Cantor::Expression* expression, expressionQueue())
+        const auto expressions = expressionQueue();
+        for (Cantor::Expression* expression : expressions)
             expression->setStatus(Cantor::Expression::Interrupted);
         expressionQueue().clear();
 
