@@ -10,7 +10,6 @@
 #include <QApplication>
 #include <KAboutData>
 #include <KCrash>
-#include <Kdelibs4ConfigMigrator>
 #include <KLocalizedString>
 #include <KConfigGroup>
 #include <KMessageBox>
@@ -20,6 +19,7 @@
 #include <QFileInfo>
 #include <QDir>
 #include <QDebug>
+
 #ifdef HAVE_EMBEDDED_DOCUMENTATION
 #include <QtWebEngine>
 #endif
@@ -28,13 +28,12 @@ int main(int argc, char **argv)
 {
 #ifdef HAVE_EMBEDDED_DOCUMENTATION
     QtWebEngine::initialize();
+
     // Register custom scheme handler for qthelp:// scheme
     QWebEngineUrlScheme qthelp("qthelp");
     QWebEngineUrlScheme::registerScheme(qthelp);
 #endif
 
-    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     // Add our custom plugins path, where we install our plugins, if it isn't default path
@@ -59,12 +58,6 @@ int main(int argc, char **argv)
             << QLatin1String("cantor_plot3d_assistant.rc") << QLatin1String("cantor_runscript_assistant.rc")
             << QLatin1String("cantor_solve_assistant.rc") << QLatin1String("cantor_qalculateplotassistant.rc");
 
-    Kdelibs4ConfigMigrator migrator(QLatin1String("cantor"));
-
-    migrator.setConfigFiles(configFiles);
-    migrator.setUiFiles(rcFiles);
-    migrator.migrate();
-    //**********************************
 
     KLocalizedString::setApplicationDomain("cantor");
     app.setApplicationName(QLatin1String("cantor"));
@@ -107,7 +100,7 @@ int main(int argc, char **argv)
 
     // see if we are starting with session management
     if (app.isSessionRestored())
-        RESTORE(CantorShell)
+        kRestoreMainWindows<CantorShell>();
     else
     {
         // no session.. just start up normally
